Arbor
=====

The Arbor Python package is a wrapper around the high-performance C++
library Arbor, for constructing and running simulations
multi-compartment neuron models, from single cell models to large
networks.

Documentation is available online at `Read the
Docs <https://docs.arbor-sim.org/en/latest/python>`__.

`Submit a ticket <https://github.com/arbor-sim/arbor>`__ if you have any
questions or want help.
